
def add_one(number):
    return number + 1



def vcounts21(x):
    # Injesting the pandas dataframe
    wsources = list(x['SOURCEURLS'])
    # Bag of words
    data = ''.join(wsources)
    data = data.split("htt")

    # Cleaning

    data2 = []

    # Striping the headnews from the webaddress
    
    for line in data:
        line2 = pathlib.PurePath(line).name
        if not re.match(r"^article", line2):
            if not re.match(r'^[0-9].*', line2):
                data2.append(line2)
    # Removing tags
    clean_txt = []
    for lines in data2:
        desc = lines.lower()

        #remove punctuation
        desc = re.sub('[^a-zA-Z]', ' ', desc)

        #remove tags
        desc=re.sub("&lt;/?.*?&gt;"," &lt;&gt; ",desc)

        #remove digits and special chars
        desc=re.sub("(\\d|\\W)+"," ",desc)

        desc=desc.replace("-", ' ')
    
        desc=desc.replace("html", '')
        desc=desc.replace("<UDIV>", '')
        desc=desc.replace("udiv", '')
        clean_txt.append(desc)    
 
        # Deleting phrases
        for i in clean_txt[:]:
            if len(i) <= 25:
                clean_txt.remove(i)
        # A second whitespace removal
        data3=[]
        for i in clean_txt:
            data3.append(i.strip())
        
        # Removing duplicates
        data3 = remove_duplicates(data3)
    return data3



def add_one(number):
    return number + 1

def vcount23():
    data4 = pd.DataFrame(data3)
    data5=data4[0].apply(clean_text)
    vect =TfidfVectorizer(stop_words=stop_words,max_features=1000)
    vect_text=vect.fit_transform(data5)
    lda_model=LatentDirichletAllocation(n_components=20,
    learning_method='online',random_state=42,max_iter=1) 
    lda_top=lda_model.fit_transform(vect_text)
    vocab = vect.get_feature_names()
    for i, comp in enumerate(lda_model.components_):
        vocab_comp = zip(vocab, comp)
        sorted_words = sorted(vocab_comp, key= lambda x:x[1], reverse=True)[:20]
        print("Topic "+str(i+1)+": ")
        for t in sorted_words:
            print(t[0], end=" ")
        print("\n")



def add_one(number):
    return number + 1


def vcounts22():
    
    dataw = ''.join(data3)
    wordcloud = WordCloud(width= 1000, height = 600, max_words=1000,
                          random_state=1, background_color='gray', colormap='viridis_r',
                          collocations=False, stopwords = STOPWORDS).generate(sum)
    plt.figure(figsize=(30, 20))
    plt.imshow(wordcloud) 
    plt.axis("off")
    plt.show()
